==> phpAdsNew_1.6.2.tar.gz: phpAdsNew_1.6.2/polish.inc.php <==
<?
/* Charset: ISO-8859-2 */
$strHome = "Home";
$date_format = "%d/%m/%Y";
$time_format = "%H:%i:%S";
$strMySQLError = "MySQl-Bd:";
$strAdminstration = "Administacja";
$strAddClient = "Dodaj nowego klienta";
$strModifyClient = "Modyfikuj klienta";
$strDeleteClient = "Usu klienta";
$strViewClientStats = "Statystyki";
$strClientName = "Klient";
$strContact = "Kontakt";
$strEMail = "EMail";
$strViews = "Wywietlenia";
$strClicks = "Kliknicia";
$strTotalViews = "Wszystkich wywietle";
$strTotalClicks = "Wszystkich klikni";
$strCTR = "Click-Throuh Ratio";
$strTotalClients = "Total clients";
$strActiveClients = "Active clients";
$strActiveBanners = "Active banners";
$strLogout = "Logout";
$strCreditStats = "Credit Stats";
$strViewCredits = "Adview credits";   
$strClickCredits = "Adclick credits";
$strPrevious = "Previous";
$strNext = "Next";
$strNone = "None";
$strViewsPurchased = "Opaconych wywietle";
$strClicksPurchased = "Opaconych klikni";
$strDaysPurchased = "AdDays purchased";
$strHTML = "HTML";
$strAddSep = "Fill in EITHER the fields above OR the field below!";
$strTextBelow = "Tekst poniej obrazka";
$strSubmit = "Wylij banner";
$strUsername = "Identyfikator";
$strPassword = "Haso";
$strBannerAdmin = "Admiministacja bannerem dla";
$strBannerAdminAcl = "Banner ACL adminstration for";
$strNoBanners = "Brak bannerw";
$strBanner = "Banner";
$strCurrentBanner = "Aktualny banner";
$strDelete = "Usu";
$strAddBanner  = "Dodan nowy banner";
$strModifyBanner  = "Modyfikuj banner";
$strModifyBannerAcl  = "Modify banner ACL";
$strURL = "URL Link z bannera(docz http://)";
$strKeyword = "Keyword";
$strWeight = "Weight";
$strAlt = "Tekst zastpczy (Alt)";
$strAccessDenied = "Dostp zabroniony";
$strNotAdmin = "Nie masz uprawnie administratora";
$strClientAdded = "Klient zosta dodany.";
$strClientModified = "Klient zosta zmodyfikowany.";
$strClientDeleted = "Klient zosta usunity. ";
$strBannerAdmin = "Administracja systemem wymiany bannerw.";
$strBannerAdded = "Banner zosta dodany.";
$strBannerModified = "Banner zosta zmodyfikowany.";
$strBannerDeleted = "Banner zosta skasowany. ";
$strBannerChanged = "Banner zosta zmieniony";
$strStats = "Statystyki";
$strDailyStats = "Statystyki dzienne";
$strDetailStats = "Dokadne statystyki";
$strCreditStats = "Credit statistics";
$strActive = "aktywny";
$strActivate = "Aktywacja";
$strDeActivate = "De-aktywacja";
$strAuthentification = "Autoryzacja";
$strGo = "Id";
$strLinkedTo = "Poczony do";
$strBannerID = "ID Bannera";
$strClientID = "ID klienta";
$strMailSubject = "Raport systemu bannerw";
$strMailSubjectDeleted = "Deactivated Ads";
$strMailHeader = 'Drogi(a) ".$clients[$i][contact].",\n';
$strMailBannerStats = 'Poniej znajduje si statystyka dla ".$clients[$i][clientname].":';
$strMailFooter = 'Z pozdrowieniami,\n   $phpAds_admin_fullname';
$strMailNothingLeft = 'Nie posiadasz ju opaconych wywietle na swoim koncie. Twoje bannery zostay wyczone.\n\nJeeli porzebujesz dodatkowych wywietle prosze sie z nami skontaktowa. Bardzo chtnie bedzie to nam slysze.\n';
$strLogMailSent = "[Wymiana Bannerw] Statystyki zostay pomylnie wysane.";
$strLogErrorClients = "[Wymiana Bannerw] Wystpi bd w czasie wyszukiwania klienta w bazie.";
$strLogErrorBanners = "[Wymiana Bannerw] Wystpi bd w czasie wyszukiwania bannera w bazie.";
$strLogErrorViews = "[Wymiana Bannerw] Wystpi bd w czasie odczytu statystyk wywietle z bazy.";
$strLogErrorClicks = "[Wymiana Bannerw] Wystpi bd w czasie odczytu statystyk klikni z bazy.";
$strLogErrorDisactivate = "[Wymiana Bannerw] Wystpi bd w czasie prby wyczenia bannera.";
$strRatio = "[Kliknij przez RATIO]";
$strChooseBanner = "Prosz wybra typ bannera.";
$strMySQLBanner = "Banner zosta dopisany do bazy";
$strURLBanner = "Banner wczytany przy pomocy linka";
$strHTMLBanner = "Banner HTML";
$strNewBannerFile = "Nowy plik bannera";
$strNewBannerURL = "Adres nowego bannera (zawiera. http://)";
$strWidth = "Szeroko";
$strHeight = "Wysoko";
$strTotalViews7Days = "Total AdViews in past 7 days";
$strTotalClicks7Days = "Total AdClicks in past 7 days";
$strAvgViews7Days = "Average AdViews in past 7 days";
$strAvgClicks7Days = "Average AdClicks in past 7 days";
$strTopTenHosts = "Top ten requesting hosts";
$strConfirmDeleteClient = "Do you really want to delete this client?";
$strClientIP = "Client IP";
$strUserAgent = "User agent regexp";
$strWeekDay = "Week day (0 - 6)";
$strDomain = "Domain (excluding dot)";
$strSource = "Source";
$strTime = "Time";
$strAllow = "Allow";
$strDeny = "Deny";
$strResetStats = "Reset Statistics";
?>

==> phpAdsNew_1.8.0.tar.gz: phpAdsNew_1.8.0/polish.inc.php <==
<?
/* Charset: ISO-8859-2 */
$strHome = "Home";
$date_format = "%d/%m/%Y";
$time_format = "%H:%i:%S";
$strMySQLError = "MySQl-Bd:";
$strAdminstration = "Administacja";
$strAddClient = "Dodaj nowego klienta";
$strModifyClient = "Modyfikuj klienta";
$strDeleteClient = "Usu klienta";
$strViewClientStats = "Statystyki";
$strClientName = "Klient";
$strContact = "Kontakt";
$strEMail = "EMail";
$strViews = "Wywietlenia";
$strClicks = "Kliknicia";
$strTotalViews = "Wszystkich wywietle";
$strTotalClicks = "Wszystkich klikni";
$strCTR = "Click-Through Ratio";
$strTotalClients = "Total clients";
$strActiveClients = "Active clients";
$strActiveBanners = "Active banners";
$strLogout = "Logout";
$strCreditStats = "Credit Stats";
$strViewCredits = "Adview credits";   
$strClickCredits = "Adclick credits";
$strPrevious = "Previous";
$strNext = "Next";
$strNone = "None";
$strViewsPurchased = "Opaconych wywietle";
$strClicksPurchased = "Opaconych klikni";
$strDaysPurchased = "AdDays purchased";
$strHTML = "HTML";
$strAddSep = "Fill in EITHER the fields above OR the field below!";
$strTextBelow = "Tekst poniej obrazka";
$strSubmit = "Wylij banner";
$strUsername = "Identyfikator";
$strPassword = "Haso";
$strBannerAdmin = "Admiministacja bannerem dla";
$strBannerAdminAcl = "Banner ACL adminstration for";
$strNoBanners = "Brak bannerw";
$strBanner = "Banner";
$strCurrentBanner = "Aktualny banner";
$strDelete = "Usu";
$strAddBanner  = "Dodan nowy banner";
$strModifyBanner  = "Modyfikuj banner";
$strModifyBannerAcl  = "Modify banner ACL";
$strURL = "URL Link z bannera(docz http://)";
$strKeyword = "Keyword";
$strWeight = "Weight";
$strAlt = "Tekst zastpczy (Alt)";
$strAccessDenied = "Dostp zabroniony";
$strNotAdmin = "Nie masz uprawnie administratora";
$strClientAdded = "Klient zosta dodany.";
$strClientModified = "Klient zosta zmodyfikowany.";
$strClientDeleted = "Klient zosta usunity. ";
$strBannerAdmin = "Administracja systemem wymiany bannerw.";
$strBannerAdded = "Banner zosta dodany.";
$strBannerModified = "Banner zosta zmodyfikowany.";
$strBannerDeleted = "Banner zosta skasowany. ";
$strBannerChanged = "Banner zosta zmieniony";
$strStats = "Statystyki";
$strDailyStats = "Statystyki dzienne";
$strDetailStats = "Dokadne statystyki";
$strCreditStats = "Credit statistics";
$strActive = "aktywny";
$strActivate = "Aktywacja";
$strDeActivate = "De-aktywacja";
$strAuthentification = "Autoryzacja";
$strGo = "Id";
$strLinkedTo = "Poczony do";
$strBannerID = "ID Bannera";
$strClientID = "ID klienta";
$strMailSubject = "Raport systemu bannerw";
$strMailSubjectDeleted = "Deactivated Ads";
$strMailHeader = 'Drogi(a) ".$clients[$i][contact].",\n';
$strMailBannerStats = 'Poniej znajduje si statystyka dla ".$clients[$i][clientname].":';
$strMailFooter = 'Z pozdrowieniami,\n   $phpAds_admin_fullname';
$strMailNothingLeft = 'Nie posiadasz ju opaconych wywietle na swoim koncie. Twoje bannery zostay wyczone.\n\nJeeli porzebujesz dodatkowych wywietle prosze sie z nami skontaktowa. Bardzo chtnie bedzie to nam slysze.\n';
$strLogMailSent = "[Wymiana Bannerw] Statystyki zostay pomylnie wysane.";
$strLogErrorClients = "[Wymiana Bannerw] Wystpi bd w czasie wyszukiwania klienta w bazie.";
$strLogErrorBanners = "[Wymiana Bannerw] Wystpi bd w czasie wyszukiwania bannera w bazie.";
$strLogErrorViews = "[Wymiana Bannerw] Wystpi bd w czasie odczytu statystyk wywietle z bazy.";
$strLogErrorClicks = "[Wymiana Bannerw] Wystpi bd w czasie odczytu statystyk klikni z bazy.";
$strLogErrorDisactivate = "[Wymiana Bannerw] Wystpi bd w czasie prby wyczenia bannera.";
$strRatio = "[Kliknij przez RATIO]";
$strChooseBanner = "Prosz wybra typ bannera.";
$strMySQLBanner = "Banner zosta dopisany do bazy";
$strURLBanner = "Banner wczytany przy pomocy linka";
$strHTMLBanner = "Banner HTML";
$strNewBannerFile = "Nowy plik bannera";
$strNewBannerURL = "Adres nowego bannera (zawiera. http://)";
$strWidth = "Szeroko";
$strHeight = "Wysoko";
$strTotalViews7Days = "Total AdViews in past 7 days";
$strTotalClicks7Days = "Total AdClicks in past 7 days";
$strAvgViews7Days = "Average AdViews in past 7 days";
$strAvgClicks7Days = "Average AdClicks in past 7 days";
$strTopTenHosts = "Top ten requesting hosts";
$strConfirmDeleteClient = "Do you really want to delete this client?";
$strClientIP = "Client IP";
$strUserAgent = "User agent regexp";
$strWeekDay = "Week day (0 - 6)";
$strDomain = "Domain (excluding dot)";
$strSource = "Source";
$strTime = "Time";
$strAllow = "Allow";
$strDeny = "Deny";
$strResetStats = "Reset Statistics";
$strConfirmResetStats = "Do you really want to reset stats for this client ?";
$strExpiration = "Expiration";
$strDaysLeft = "Days left";
$strEstimated = "Estimated expiration";
$strConfirm = "Are you sure ?";
$strBannerNoStats = "No statistics available for this banner!";
$strWeek = "Week";
$strWeeklyStats = "Weekly statistics";
$strWeekDay = "Weekday";
$strDate = "Date";
$strCTRShort = "CTR";
$strDayShortCuts=array("Su","Mo","Tu","We","Th","Fr","Sa");
$strShowWeeks="Max. weeks to display";
$strAll="all";
$strAvg="Avg.";
$strHourly="Views/Clicks by hour";
$strTotal = "Total";
$strUnlimited = "Unlimited";

?>
